aboutsummaryrefslogtreecommitdiff
path: root/test/run.go
diff options
context:
space:
mode:
authorKeith Randall <khr@golang.org>2020-10-01 14:49:33 -0700
committerKeith Randall <khr@golang.org>2020-10-02 00:00:51 +0000
commitfe2cfb74ba6352990f5b41260b99e80f78e4a90a (patch)
treeeb0fe4e5c26627df259f080b14c2dc00750af8b2 /test/run.go
parent41df0e22184a0fcfb1e67e994c993239e9c2efc7 (diff)
downloadgo-fe2cfb74ba6352990f5b41260b99e80f78e4a90a.tar.gz
go-fe2cfb74ba6352990f5b41260b99e80f78e4a90a.zip
all: drop 387 support
My last 387 CL. So sad ... ... ... ... not! Fixes #40255 Change-Id: I8d4ddb744b234b8adc735db2f7c3c7b6d8bbdfa4 Reviewed-on: https://go-review.googlesource.com/c/go/+/258957 Trust: Keith Randall <khr@golang.org> Run-TryBot: Keith Randall <khr@golang.org> TryBot-Result: Go Bot <gobot@golang.org> Reviewed-by: Cherry Zhang <cherryyz@google.com>
Diffstat (limited to 'test/run.go')
-rw-r--r--test/run.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/run.go b/test/run.go
index 95b94b7277..77710fd89a 100644
--- a/test/run.go
+++ b/test/run.go
@@ -1489,7 +1489,7 @@ var (
// value[0] is the variant-changing environment variable, and values[1:]
// are the supported variants.
archVariants = map[string][]string{
- "386": {"GO386", "387", "sse2"},
+ "386": {},
"amd64": {},
"arm": {"GOARM", "5", "6", "7"},
"arm64": {},
@@ -1511,12 +1511,12 @@ type wantedAsmOpcode struct {
found bool // true if the opcode check matched at least one in the output
}
// A build environment triplet separated by slashes (eg: linux/386/sse2).
// The third field can be empty if the arch does not support variants (eg: "plan9/amd64/")
type buildEnv string
// Environ returns the environment it represents in cmd.Environ() "key=val" format
-// For instance, "linux/386/sse2".Environ() returns {"GOOS=linux", "GOARCH=386", "GO386=sse2"}
+// For instance, "linux/arm/7".Environ() returns {"GOOS=linux", "GOARCH=arm", "GOARM=7"}
func (b buildEnv) Environ() []string {
fields := strings.Split(string(b), "/")
if len(fields) != 3 {
@@ -1571,11 +1571,11 @@ func (t *test) wantedAsmOpcodes(fn string) asmChecks {
var arch, subarch, os string
switch {
- case archspec[2] != "": // 3 components: "linux/386/sse2"
+ case archspec[2] != "": // 3 components: "linux/arm/7"
os, arch, subarch = archspec[0], archspec[1][1:], archspec[2][1:]
- case archspec[1] != "": // 2 components: "386/sse2"
+ case archspec[1] != "": // 2 components: "arm/7"
os, arch, subarch = "linux", archspec[0], archspec[1][1:]
- default: // 1 component: "386"
+ default: // 1 component: "arm"
os, arch, subarch = "linux", archspec[0], ""
if arch == "wasm" {
os = "js"
@@ -1511,12 +1511,12 @@ type wantedAsmOpcode struct {
found bool // true if the opcode check matched at least one in the output
}
-// A build environment triplet separated by slashes (eg: linux/386/sse2).
+// A build environment triplet separated by slashes (eg: linux/arm/7).
// The third field can be empty if the arch does not support variants (eg: "plan9/amd64/")
type buildEnv string